Документация по серверу борьбы со спамом “СпамоБорец” — СпамоБорец: документация

### Navigation

- index
- next |
- СпамоБорец: документация »

# Документация по серверу борьбы со спамом “СпамоБорец”

СпамоБорец - веб-сервис, предоставляющий функции по классификации произвольных текстовых сообщений, и, в частности, выделения спама из общего потока сообщений.

В качестве сообщений могут рассматриваться, например, следующие виды общения, которые сегодня есть в социальных сетях (и веб-сайтах, имеющих элементы социальной сети):

- личные сообщения;
- чаты;
- комментарии к произвольным объектам;
- девизы, сообщения “о себе” и т.п. на страницах профиля пользователя;
- письма в службу поддержки.

Фильтрация и классификация сообщений основывается на нескольких независимых алгоритмах; результатом классификации может являться классификация как самого сообщения (причём, возможно, по нескольким категориям: спам, флуд, проституция и т.п.), так и классификация отправителей сообщений (как авторизованных, так и неавторизованных, по тем же самым категориям: спамер, флудер и т.п.). Применение классификации к отправителям сообщений позволяет на раннем этапе пресекать попытки спам-рассылок и тому подобных массовых действий на сайте.

## Содержание

- Введение
  - Варианты размещения

- Руководство пользователя
  - Обзор возможностей СпамоБорца
  - Установка СпамоБорца
  - Запуск сервера
  - Основные компоненты сервера
  - Настройка сервера

- API СпамоБорца
  - Транспорт API
  - Типы данных
  - Информационные команды
  - Команды работы с сообщениями
  - Команды управления доменами
  - Команды управления моделью анализа сообщений
  - Клиенты API

- Руководство разработчика
  - Установка и подготовка
  - Работа с документацией

## Индексы и таблицы

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- СпамоБорец: документация »